package com.huimv.env.common.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.common.utils.DataUill;
import com.huimv.env.common.entity.BasePigpen;
import com.huimv.env.common.entity.EnergyData;
import com.huimv.env.common.entity.EnergyElectricity;
import com.huimv.env.common.entity.EnergyWater;
import com.huimv.env.common.entity.dto.EnergyDto;
import com.huimv.env.common.entity.vo.EnergyAllDataVo;
import com.huimv.env.common.entity.vo.EnergyDataVo;
import com.huimv.env.common.mapper.BasePigpenMapper;
import com.huimv.env.common.mapper.EnergyDataMapper;
import com.huimv.env.common.mapper.EnergyElectricityMapper;
import com.huimv.env.common.mapper.EnergyWaterMapper;
import com.huimv.env.common.service.IEnergyDataService;
import com.huimv.env.common.utils.Result;
import com.huimv.env.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.text.DecimalFormat;
import java.util.*;

/**
 * <p>
 * 耗能数据 服务实现类
 * </p>
 *
 * @author author
 * @since 2023-02-14
 */
@Service
public class EnergyDataServiceImpl extends ServiceImpl<EnergyDataMapper, EnergyData> implements IEnergyDataService {

    @Autowired
    private EnergyDataMapper dataMapper;
    @Autowired
    private BasePigpenMapper basePigpenMapper;
    @Autowired
    private EnergyWaterMapper waterMapper;
    @Autowired
    private EnergyElectricityMapper electricityMapper;
//    @Autowired
//    private EnergyWarningInfoMapper warningInfoMapper;

    @Override
    public Result listCount(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        QueryWrapper<EnergyData> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId);
        EnergyDataVo energyDataVo = dataMapper.listCount(queryWrapper);
//        QueryWrapper<EnergyWarningInfo> queryWrapper1 = new QueryWrapper<>();
//        queryWrapper1.eq("farm_id", farmId);
//        Integer count = warningInfoMapper.selectCount(queryWrapper1);
////        Float f = 0.00f;
////        f = (Float.parseFloat(energyDataVo.getElectricityValue()) +
////                Float.parseFloat(energyDataVo.getFeedValue()) +
////                Float.parseFloat(energyDataVo.getGasValue()) + Float.parseFloat(energyDataVo.getWaterValue()));
////        DecimalFormat df1 = new DecimalFormat("#.00");
//        energyDataVo.setCount(count);
        return new Result(ResultCode.SUCCESS, energyDataVo);
    }

    @Override
    public Result listData(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String dataType = paramsMap.get("dataType");
        String timeType = paramsMap.get("timeType");
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");

        if (dataType == null || dataType == "") {
            dataType = "1";
        }
        if (timeType == null || timeType == "") {
            timeType = "3";
        }

        QueryWrapper<EnergyData> dataQueryWrapper = new QueryWrapper<>();
        dataQueryWrapper.eq("farm_id", farmId);
        //用水
        if ("1".equals(dataType)) {
            //自定义
            if ("4".equals(timeType)) {
                startTime = startTime + " 00:00:00";
                endTime = endTime + " 23:59:59";
                dataQueryWrapper.between("create_date", startTime, endTime);
                return new Result(ResultCode.SUCCESS, dataMapper.listDayWater(dataQueryWrapper));
            }
            //全年
            if ("3".equals(timeType)) {
                DateTime dateTime = DateUtil.beginOfYear(new Date());
                dataQueryWrapper.ge("create_date", dateTime);
                List<EnergyAllDataVo> energyWaterDataVos = dataMapper.listYearWater(dataQueryWrapper);
                return new Result(ResultCode.SUCCESS, energyWaterDataVos);
            }
            //本月
            if ("2".equals(timeType)) {
                Date timesMonthmorning = DataUill.getTimesMonthmorning();
                dataQueryWrapper.ge("create_date", timesMonthmorning);
                return new Result(ResultCode.SUCCESS, dataMapper.listDayWater(dataQueryWrapper));
            }
            //本周
            if ("1".equals(timeType)) {
                Calendar calendar = Calendar.getInstance();
                calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
                dataQueryWrapper.ge("create_date", calendar.getTime());
                List<EnergyAllDataVo> energyWaterDataVos = dataMapper.listDayWater(dataQueryWrapper);
                return new Result(ResultCode.SUCCESS, energyWaterDataVos);
            }
        }
        //用电
        else if ("2".equals(dataType)) {
            //自定义
            if ("4".equals(timeType)) {
                startTime = startTime + " 00:00:00";
                endTime = endTime + " 23:59:59";
                dataQueryWrapper.between("create_date", startTime, endTime);
                return new Result(ResultCode.SUCCESS, dataMapper.listDayElectricity(dataQueryWrapper));
            }
            //全年
            if ("3".equals(timeType)) {
                DateTime dateTime = DateUtil.beginOfYear(new Date());
                dataQueryWrapper.ge("create_date", dateTime);
                List<EnergyAllDataVo> energyElectricityDataVos = dataMapper.listYearElectricity(dataQueryWrapper);
                return new Result(ResultCode.SUCCESS, energyElectricityDataVos);
            }
            //本月
            if ("2".equals(timeType)) {
                Date timesMonthmorning = DataUill.getTimesMonthmorning();
                dataQueryWrapper.ge("create_date", timesMonthmorning);
                return new Result(ResultCode.SUCCESS, dataMapper.listDayElectricity(dataQueryWrapper));
            }
            //本周
            if ("1".equals(timeType)) {
                Calendar calendar = Calendar.getInstance();
                calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
                dataQueryWrapper.ge("create_date", calendar.getTime());
                List<EnergyAllDataVo> energyElectricityDataVos = dataMapper.listDayElectricity(dataQueryWrapper);
                return new Result(ResultCode.SUCCESS, energyElectricityDataVos);
            }
        }
//        //饲料
//        else if ("3".equals(dataType)) {
//            //自定义
//            if ("4".equals(timeType)) {
//                startTime = startTime + " 00:00:00";
//                endTime = endTime + " 23:59:59";
//                dataQueryWrapper.between("create_date", startTime, endTime);
//                return new Result(ResultCode.SUCCESS, dataMapper.listDayFeed(dataQueryWrapper));
//            }
//            //全年
//            if ("3".equals(timeType)) {
//                DateTime dateTime = DateUtil.beginOfYear(new Date());
//                dataQueryWrapper.ge("create_date", dateTime);
//                List<EnergyAllDataVo> energyFeedDataVos = dataMapper.listYearFeed(dataQueryWrapper);
//                return new Result(ResultCode.SUCCESS, energyFeedDataVos);
//            }
//            //本月
//            if ("2".equals(timeType)) {
//                Date timesMonthmorning = DataUill.getTimesMonthmorning();
//                dataQueryWrapper.ge("create_date", timesMonthmorning);
//                return new Result(ResultCode.SUCCESS, dataMapper.listDayFeed(dataQueryWrapper));
//            }
//            //本周
//            if ("1".equals(timeType)) {
//                Calendar calendar = Calendar.getInstance();
//                calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
//                dataQueryWrapper.ge("create_date", calendar.getTime());
//                List<EnergyAllDataVo> energyFeedDataVos = dataMapper.listDayFeed(dataQueryWrapper);
//                return new Result(ResultCode.SUCCESS, energyFeedDataVos);
//            }
//        }
//        //天然气
//        else if ("4".equals(dataType)) {
//            //自定义
//            if ("4".equals(timeType)) {
//                startTime = startTime + " 00:00:00";
//                endTime = endTime + " 23:59:59";
//                dataQueryWrapper.between("create_date", startTime, endTime);
//                return new Result(ResultCode.SUCCESS, dataMapper.listDayGas(dataQueryWrapper));
//            }
//            //全年
//            if ("3".equals(timeType)) {
//                DateTime dateTime = DateUtil.beginOfYear(new Date());
//                dataQueryWrapper.ge("create_date", dateTime);
//                List<EnergyAllDataVo> energyGasDataVos = dataMapper.listYearGas(dataQueryWrapper);
//                return new Result(ResultCode.SUCCESS, energyGasDataVos);
//            }
//            //本月
//            if ("2".equals(timeType)) {
//                Date timesMonthmorning = DataUill.getTimesMonthmorning();
//                dataQueryWrapper.ge("create_date", timesMonthmorning);
//                return new Result(ResultCode.SUCCESS, dataMapper.listDayGas(dataQueryWrapper));
//            }
//            //本周
//            if ("1".equals(timeType)) {
//                Calendar calendar = Calendar.getInstance();
//                calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
//                dataQueryWrapper.ge("create_date", calendar.getTime());
//                List<EnergyAllDataVo> energyGasDataVos = dataMapper.listDayGas(dataQueryWrapper);
//                return new Result(ResultCode.SUCCESS, energyGasDataVos);
//            }
//        }
        return new Result(ResultCode.SUCCESS);
    }

    @Override
    public Result listRank(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String dataType = paramsMap.get("dataType");
        String timeType = paramsMap.get("timeType");
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");
        if (dataType == null || dataType == "") {
            dataType = "1";
        }
        if (timeType == null || timeType == "") {
            timeType = "3";
        }
        QueryWrapper<BasePigpen> basePigpenQueryWrapper = new QueryWrapper<>();
        basePigpenQueryWrapper.eq("farm_id", farmId);
        JSONArray jsonArray = new JSONArray();
        basePigpenQueryWrapper.eq("parent_id", 0);
        List<BasePigpen> basePigpens = basePigpenMapper.selectList(basePigpenQueryWrapper);//得到所有的栋舍
        for (BasePigpen basePigpen : basePigpens) {
            QueryWrapper<BasePigpen> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_id", farmId).eq("parent_id", basePigpen.getId()).eq("f_type", 2);
            List<BasePigpen> pigpens = basePigpenMapper.selectList(queryWrapper);//得到所有的楼层
            Float value = 0.00f;
            for (BasePigpen pigpen : pigpens) {
                QueryWrapper<BasePigpen> queryWrapper1 = new QueryWrapper<>();
                queryWrapper1.like("other2", pigpen.getId()).eq("farm_id", farmId);
                List<BasePigpen> basePigpens1 = basePigpenMapper.selectList(queryWrapper1);
                List<Integer> idList = new ArrayList<>();
                basePigpens1.forEach(item -> {
                    idList.add(item.getId());
                });//某一层所有单元的id
                QueryWrapper<EnergyData> dataQueryWrapper = new QueryWrapper<>();
                if (ObjectUtil.isNotEmpty(idList)) {
                    dataQueryWrapper.eq("farm_id", farmId).in("unit_id", idList);
                } else {
                    dataQueryWrapper.eq("farm_id", farmId);
                }


                if ("4".equals(timeType)) {
                    //自定义
                    startTime = startTime + " 00:00:00";
                    endTime = endTime + " 23:59:59";
                    dataQueryWrapper.between("create_date", startTime, endTime);
                } else if ("3".equals(timeType)) {
                    //本年
                    DateTime dateTime = DateUtil.beginOfYear(new Date());
                    dataQueryWrapper.ge("create_date", dateTime);
                } else if ("2".equals(timeType)) {
                    //本月
                    Date timesMonthmorning = DataUill.getTimesMonthmorning();
                    dataQueryWrapper.ge("create_date", timesMonthmorning);
                } else if ("1".equals(timeType)) {
                    //本周
                    Calendar calendar = Calendar.getInstance();
                    calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
                    dataQueryWrapper.ge("create_date", calendar.getTime());
                }


                dataQueryWrapper.select(
                        "IFNULL(SUM(water_value),0) waterValue,IFNULL(SUM(gas_value),0) gasValue" +
                                ",IFNULL(SUM(electricity_value),0) electricityValue" +
                                ",IFNULL(SUM(feed_value),0) feedValue  "
                );
                EnergyData energyData = dataMapper.selectOne(dataQueryWrapper);
                JSONObject jsonObject = new JSONObject();


                if ("1".equals(dataType)) {
                    if (Float.parseFloat(energyData.getWaterValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getWaterValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                if ("2".equals(dataType)) {
                    if (Float.parseFloat(energyData.getElectricityValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getElectricityValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                if ("3".equals(dataType)) {
                    if (Float.parseFloat(energyData.getFeedValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getFeedValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                if ("4".equals(dataType)) {
                    if (Float.parseFloat(energyData.getGasValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getGasValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                jsonObject.put("buildName", pigpen.getBuildName());
                jsonArray.add(jsonObject);
                value = 0.00f;
            }
        }

        JSONArray arraySort = jsonArraySort(jsonArray, "value", true);
        return new Result(ResultCode.SUCCESS, arraySort);
    }

    @Override
    public Result listDataScreen(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        QueryWrapper<EnergyData> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId);
//        List<EnergyAllDataVo> energyGasDataVos = dataMapper.listDayGas(queryWrapper);
//        List<EnergyAllDataVo> energyFeedDataVos = dataMapper.listDayFeed(queryWrapper);
        List<EnergyAllDataVo> energyWaterDataVos = dataMapper.listDayWater(queryWrapper);
        List<EnergyAllDataVo> energyElectricityDataVos = dataMapper.listDayElectricity(queryWrapper);
        JSONObject jsonObject = new JSONObject();
//        jsonObject.put("gas", energyGasDataVos);
        jsonObject.put("water", energyWaterDataVos);
        jsonObject.put("energyElectricity", energyElectricityDataVos);
//        jsonObject.put("feed", energyFeedDataVos);
        return new Result(ResultCode.SUCCESS, jsonObject);
    }

    @Override
    public Result listRankScreen(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String dataType = paramsMap.get("dataType");
        if (dataType == null || dataType == "") {
            dataType = "1";
        }
        QueryWrapper<BasePigpen> basePigpenQueryWrapper = new QueryWrapper<>();
        basePigpenQueryWrapper.eq("farm_id", farmId);
        JSONArray jsonArray = new JSONArray();
        basePigpenQueryWrapper.eq("parent_id", 0);
        List<BasePigpen> basePigpens = basePigpenMapper.selectList(basePigpenQueryWrapper);//得到所有的栋舍
        for (BasePigpen basePigpen : basePigpens) {
            QueryWrapper<BasePigpen> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_id", farmId).eq("parent_id", basePigpen.getId()).eq("f_type", 2);
            List<BasePigpen> pigpens = basePigpenMapper.selectList(queryWrapper);//得到所有的楼层
            Float value = 0.00f;
            for (BasePigpen pigpen : pigpens) {
                QueryWrapper<BasePigpen> queryWrapper1 = new QueryWrapper<>();
                queryWrapper1.like("other2", pigpen.getId()).eq("farm_id", farmId);
                List<BasePigpen> basePigpens1 = basePigpenMapper.selectList(queryWrapper1);
                List<Integer> idList = new ArrayList<>();
                basePigpens1.forEach(item -> {
                    idList.add(item.getId());
                });//某一层所有单元的id
                QueryWrapper<EnergyData> dataQueryWrapper = new QueryWrapper<>();
                if (ObjectUtil.isNotEmpty(idList)) {
                    dataQueryWrapper.eq("farm_id", farmId).in(("unit_id"), idList);
                } else {
                    dataQueryWrapper.eq("farm_id", farmId);
                }


                dataQueryWrapper.select(
                        "IFNULL(SUM(water_value),0) waterValue,IFNULL(SUM(gas_value),0) gasValue" +
                                ",IFNULL(SUM(electricity_value),0) electricityValue" +
                                ",IFNULL(SUM(feed_value),0) feedValue  "
                );
                EnergyData energyData = dataMapper.selectOne(dataQueryWrapper);
                JSONObject jsonObject = new JSONObject();
                if ("1".equals(dataType)) {
                    if (Float.parseFloat(energyData.getWaterValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getWaterValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                if ("2".equals(dataType)) {
                    if (Float.parseFloat(energyData.getElectricityValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getElectricityValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                if ("3".equals(dataType)) {
                    if (Float.parseFloat(energyData.getFeedValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getFeedValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                if ("4".equals(dataType)) {
                    if (Float.parseFloat(energyData.getGasValue()) != 0.0f) {
                        value = value + Float.parseFloat(energyData.getGasValue());
                        jsonObject.put("value", value);
                    } else {
                        jsonObject.put("value", 0);
                    }
                }
                jsonObject.put("buildName", pigpen.getBuildName());
                jsonArray.add(jsonObject);
                value = 0.00f;
            }
        }
        JSONArray arraySort = jsonArraySort1(jsonArray, "value", true);
        JSONArray array = new JSONArray();
        if (arraySort.size() < 5) {
            return new Result(ResultCode.SUCCESS, arraySort);
        } else {
            for (int i = 0; i < 5; i++) {
                array.add(arraySort.get(i));
            }
            return new Result(ResultCode.SUCCESS, array);
        }
    }

    @Override
    public Result listAll(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");
        String deviceCode = paramsMap.get("deviceCode");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");

        if ("".equals(pageNum) || null == pageNum) {
            pageNum = "1";
        }
        if ("".equals(pageSize) || null == pageSize) {
            pageSize = "10";
        }
        String isLook = paramsMap.get("isLook");
        String id = paramsMap.get("id");
        String type = paramsMap.get("type");//1 为水 2为电
        if ("".equals(isLook) || null == isLook) {
            isLook = "1";
        }

        if ("1".equals(type)) {
            QueryWrapper<EnergyWater> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_id", farmId).eq(StringUtils.isNotBlank(id), "unit_id", id);
            queryWrapper.between(StringUtils.isNotBlank(startTime), "create_date", startTime, endTime).orderByDesc("create_date");
            if (isLook.equals("0")) {
                queryWrapper.ne("water_value", 0);
            }
            queryWrapper.eq(StringUtils.isNotBlank(deviceCode), "chip_code", deviceCode);
            Page<EnergyWater> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
            return new Result(ResultCode.SUCCESS, waterMapper.selectPage(page, queryWrapper));
        } else {
            QueryWrapper<EnergyElectricity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_id", farmId).eq(StringUtils.isNotBlank(id), "unit_id", id);
            queryWrapper.between(StringUtils.isNotBlank(startTime), "create_date", startTime, endTime).orderByDesc("create_date");
            if (isLook.equals("0")) {
                queryWrapper.ne("electricity_value", 0);
            }
            queryWrapper.eq(StringUtils.isNotBlank(deviceCode), "chip_code", deviceCode);
            Page<EnergyElectricity> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
            return new Result(ResultCode.SUCCESS, electricityMapper.selectPage(page, queryWrapper));
        }

    }

    @Override
    public Result listAll2(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");
        String isLook = paramsMap.get("isLook");
        String id = paramsMap.get("id");
        String type = paramsMap.get("type");//1 为水 2为电
        String deviceCode = paramsMap.get("deviceCode");
        if ("".equals(isLook) || null == isLook) {
            isLook = "1";
        }
        if ("1".equals(type)) {
            QueryWrapper<EnergyWater> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_id", farmId).eq(StringUtils.isNotBlank(id), "unit_id", id)
                    .eq(StringUtils.isNotBlank(deviceCode), "chip_code", deviceCode);
            queryWrapper.between(StringUtils.isNotBlank(startTime), "create_date", startTime, endTime).orderByAsc("upload_date");
            if (isLook.equals("0")) {
                queryWrapper.ne("water_value", 0);
            }
            return new Result(ResultCode.SUCCESS, waterMapper.selectList(queryWrapper));
        } else {
            QueryWrapper<EnergyElectricity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_id", farmId).eq(StringUtils.isNotBlank(id), "unit_id", id)
                    .eq(StringUtils.isNotBlank(deviceCode), "chip_code", deviceCode);
            queryWrapper.between(StringUtils.isNotBlank(startTime), "create_date", startTime, endTime).orderByAsc("upload_date");
            if (isLook.equals("0")) {
                queryWrapper.ne("electricity_value", 0);
            }
            return new Result(ResultCode.SUCCESS, electricityMapper.selectList(queryWrapper));
        }
    }

    @Override
    public Result countEnergy(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String startTime = paramsMap.get("startTime");
        String endTime = paramsMap.get("endTime");
        String deviceCode = paramsMap.get("deviceCode");
        QueryWrapper<EnergyWater> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).between(StringUtils.isNotBlank(startTime), "create_date", startTime, endTime);
        queryWrapper.eq("chip_code", deviceCode);
        List<EnergyWater> energyWaters = waterMapper.selectList(queryWrapper);
        QueryWrapper<EnergyElectricity> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.eq("farm_id", farmId).between(StringUtils.isNotBlank(startTime), "create_date", startTime, endTime);
        queryWrapper1.eq("chip_code", deviceCode);
        List<EnergyElectricity> electricities = electricityMapper.selectList(queryWrapper1);
        Double waterCount = 0.00;
        Double electricityCount = 0.00;
        if (energyWaters.size() != 0) {
            for (EnergyWater energyWater : energyWaters) {
                waterCount = waterCount + Double.parseDouble(energyWater.getWaterValue());
            }
        }
        if (electricities.size() != 0) {
            for (EnergyElectricity electricity : electricities) {
                electricityCount = electricityCount + Double.parseDouble(electricity.getElectricityValue());
            }
        }
        DecimalFormat def = new DecimalFormat("0.0");
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("waterCount", def.format(waterCount));
        jsonObject.put("electricity", def.format(electricityCount));


        return new Result(ResultCode.SUCCESS, jsonObject);
    }


    /*数组排序*/
    public static JSONArray jsonArraySort(JSONArray jsonArr, String sortKey, boolean is_desc) {
        //存放排序结果json数组
        JSONArray sortedJsonArray = new JSONArray();
        //用于排序的list
        List<JSONObject> jsonValues = new ArrayList<JSONObject>();
        //将参数json数组每一项取出，放入list
        if (jsonArr.size() < 8) {
            for (int i = 0; i < jsonArr.size(); i++) {
                jsonValues.add(jsonArr.getJSONObject(i));
            }
            //快速排序，重写compare方法，完成按指定字段比较，完成排序
            Collections.sort(jsonValues, new Comparator<JSONObject>() {
                //排序字段
                private final String KEY_NAME = sortKey;

                //重写compare方法
                @Override
                public int compare(JSONObject a, JSONObject b) {
                    //如果用String接会导致一位数和两位数混合比对的时候不能准确比出来，要用int类型接
                    //String valA = new String();
                    //String valB = new String();
                    Float valA = 0.00f;
                    Float valB = 0.00f;
                    try {
                        valA = Float.parseFloat(a.getString(KEY_NAME));
                        valB = Float.parseFloat(b.getString(KEY_NAME));
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                    //是升序还是降序
                    if (is_desc) {
                        return -valA.compareTo(valB);
                    } else {
                        return -valB.compareTo(valA);
                    }

                }
            });
            //将排序后结果放入结果jsonArray
            for (int i = 0; i < jsonArr.size(); i++) {
                sortedJsonArray.add(jsonValues.get(i));
            }
        } else {
            for (int i = 0; i < 8; i++) {
                jsonValues.add(jsonArr.getJSONObject(i));
            }
            //快速排序，重写compare方法，完成按指定字段比较，完成排序
            Collections.sort(jsonValues, new Comparator<JSONObject>() {
                //排序字段
                private final String KEY_NAME = sortKey;

                //重写compare方法
                @Override
                public int compare(JSONObject a, JSONObject b) {
                    //如果用String接会导致一位数和两位数混合比对的时候不能准确比出来，要用int类型接
                    //String valA = new String();
                    //String valB = new String();
                    Float valA = 0.00f;
                    Float valB = 0.00f;
                    try {
                        valA = Float.parseFloat(a.getString(KEY_NAME));
                        valB = Float.parseFloat(b.getString(KEY_NAME));
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                    //是升序还是降序
                    if (is_desc) {
                        return -valA.compareTo(valB);
                    } else {
                        return -valB.compareTo(valA);
                    }

                }
            });
            //将排序后结果放入结果jsonArray
            for (int i = 0; i < 8; i++) {
                sortedJsonArray.add(jsonValues.get(i));
            }
        }

        return sortedJsonArray;
    }

    /*数组排序*/
    public static JSONArray jsonArraySort1(JSONArray jsonArr, String sortKey, boolean is_desc) {
        //存放排序结果json数组
        JSONArray sortedJsonArray = new JSONArray();
        //用于排序的list
        List<JSONObject> jsonValues = new ArrayList<JSONObject>();
        //将参数json数组每一项取出，放入list

        for (int i = 0; i < jsonArr.size(); i++) {
            jsonValues.add(jsonArr.getJSONObject(i));
        }
        //快速排序，重写compare方法，完成按指定字段比较，完成排序
        Collections.sort(jsonValues, new Comparator<JSONObject>() {
            //排序字段
            private final String KEY_NAME = sortKey;

            //重写compare方法
            @Override
            public int compare(JSONObject a, JSONObject b) {
                //如果用String接会导致一位数和两位数混合比对的时候不能准确比出来，要用int类型接
                //String valA = new String();
                //String valB = new String();
                Float valA = 0.00f;
                Float valB = 0.00f;
                try {
                    valA = Float.parseFloat(a.getString(KEY_NAME));
                    valB = Float.parseFloat(b.getString(KEY_NAME));
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                //是升序还是降序
                if (is_desc) {
                    return -valA.compareTo(valB);
                } else {
                    return -valB.compareTo(valA);
                }

            }
        });
        //将排序后结果放入结果jsonArray
        if (jsonArr.size() < 5) {
            for (int i = 0; i < jsonArr.size(); i++) {
                sortedJsonArray.add(jsonValues.get(i));
            }
        } else {
            for (int i = 0; i < 5; i++) {
                sortedJsonArray.add(jsonValues.get(i));
            }
        }
        return sortedJsonArray;
    }

}
